==> ah-formbuilder-1.0.71.tgz: package/es/components/app/App.js <==
var _jsxFileName = "/home/zaman/Documents/GitLab/bayt/formbuilder/src/components/app/App.js";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import { connect } from 'react-redux';
import CircularProgress from '@material-ui/core/CircularProgress';
import { setInitialData as _setInitialData, setPredefinedValues as _setPredefinedValues, setUsers as _setUsers, setPredefinedEndpoint as _setPredefinedEndpoint, setFileUploadUrl as _setFileUploadUrl, setOrder as _setOrder, setConditionableFields as _setConditionableFields, createField as _createField, setLocals as _setLocals, setFormId as _setFormId, setTheme as _setTheme, setCurrentLang as _setCurrentLang, setRoles as _setRoles } from '../../actions/formActions';
import MainLayout from '../../layouts/Main';
import predefined from '../../predefined-values';
import './App.scss';
import _ from 'lodash';
import axios from 'axios';
import Wrapper from './FieldWrapper';
import DroppableField from './DroppableField';
import { Scrollbars } from 'react-custom-scrollbars';
import { getHeight, generateSampleData } from '../../utils/helpers';
var noFieldMessage = {
  en: 'Looks like there are no fields in this form',
  ar: 'يبدو أنه لا توجد حقول في هذا النموذج'
};

var compare = function compare(a, b) {
  if (a.order < b.order) {
    return -1;
  }

  if (a.order > b.order) {
    return 1;
  }

  return 0;
};

var App = /*#__PURE__*/function (_Component) {
  _inheritsLoose(App, _Component);

  function App(props) {
    var _this;

    _this = _Component.call(this, props) || this;

    _defineProperty(_assertThisInitialized(_this), "handleOnDragStart", function (index) {
      _this.onDragItem = index;

      _this.setState(_extends({}, _this.state, {
        onDragExisitingField: true
      }));
    });

    _defineProperty(_assertThisInitialized(_this), "handleOnDrop", function (index, type, uuid, order, event, callback) {
      event.stopPropagation();
      var droppedFieldSlug = event.dataTransfer.getData('droppedFieldSlug');

      if (droppedFieldSlug) {
        if (type === 'section' && droppedFieldSlug !== 'section') {
          var data = generateSampleData(droppedFieldSlug, order);
          data.parentId = uuid;

          _this.props.createField(data);
        }
      } else {
        _this.onDropItem = index;

        _this.reorderFields(_this.onDragItem, _this.onDropItem);

        callback ? callback() : null;

        _this.setState(_extends({}, _this.state, {
          onDragExisitingField: false
        }));
      }
    });

    _defineProperty(_assertThisInitialized(_this), "handleFieldDrop", function (e) {
      e.preventDefault();
      var droppedFieldSlug = e.dataTransfer.getData('droppedFieldSlug');

      if (droppedFieldSlug) {
        var data = generateSampleData(droppedFieldSlug, _this.props.order);

        _this.props.createField(data);
      }
    });

    _defineProperty(_assertThisInitialized(_this), "handleFieldDropBtw", function (e, order, callback) {
      e.stopPropagation();
      var droppedFieldSlug = e.dataTransfer.getData('droppedFieldSlug');

      if (droppedFieldSlug) {
        var data = generateSampleData(droppedFieldSlug, order);

        _this.props.createField(data);
      }

      callback();
    });

    _defineProperty(_assertThisInitialized(_this), "renderFields", function () {
      //  this.fields  = this.fields.filter(field =>{
      //   if(field.parentId) return false;
      //   return true;
      // })
      var count = 0;
      var total = _this.fields.length;
      return _.map(_this.fields, function (field, index) {
        count++;
        var droppableField = /*#__PURE__*/React.createElement(DroppableField, {
          onDrop: _this.handleFieldDropBtw,
          order: field.order,
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 174,
            columnNumber: 29
          }
        });

        if (_this.state.onDragExisitingField) {
          droppableField = /*#__PURE__*/React.createElement(DroppableField, {
            onDragExisitingField: true,
            onDrop: _this.handleOnDrop,
            data: {
              index: index,
              field: field
            },
            __self: _assertThisInitialized(_this),
            __source: {
              fileName: _jsxFileName,
              lineNumber: 176,
              columnNumber: 27
            }
          });
        }

        if (count === total) {
          var lastDroppableField = /*#__PURE__*/React.createElement(DroppableField, {
            onDragExisitingField: true,
            onDrop: _this.handleOnDrop,
            data: {
              index: index + 1,
              field: field
            },
            __self: _assertThisInitialized(_this),
            __source: {
              fileName: _jsxFileName,
              lineNumber: 179,
              columnNumber: 36
            }
          });
          return [droppableField, /*#__PURE__*/React.createElement("div", {
            key: index,
            draggable: "true",
            onDragStart: function onDragStart() {
              return _this.handleOnDragStart(index);
            } // onDrop={(e) => this.handleOnDrop(index,field.type,field.uuid,field.order,e)}
            ,
            onDragOver: function onDragOver(event) {
              return event.preventDefault();
            },
            __self: _assertThisInitialized(_this),
            __source: {
              fileName: _jsxFileName,
              lineNumber: 182,
              columnNumber: 13
            }
          }, /*#__PURE__*/React.createElement("li", {
            key: 'li-' + field.uuid,
            className: "ahfb-d-block",
            __self: _assertThisInitialized(_this),
            __source: {
              fileName: _jsxFileName,
              lineNumber: 187,
              columnNumber: 15
            }
          }, /*#__PURE__*/React.createElement(Wrapper, {
            data: field,
            key: field.uuid,
            first: count === 1,
            last: count === total,
            __self: _assertThisInitialized(_this),
            __source: {
              fileName: _jsxFileName,
              lineNumber: 188,
              columnNumber: 17
            }
          }))), lastDroppableField];
        }

        return [droppableField, /*#__PURE__*/React.createElement("div", {
          draggable: "true",
          onDragStart: function onDragStart() {
            return _this.handleOnDragStart(index);
          } // onDrop={(e) => this.handleOnDrop(index,field.type,field.uuid,field.order,e)}
          ,
          onDragOver: function onDragOver(event) {
            return event.preventDefault();
          },
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 197,
            columnNumber: 9
          }
        }, /*#__PURE__*/React.createElement("li", {
          key: 'li-' + field.uuid,
          className: "ahfb-d-block",
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 202,
            columnNumber: 9
          }
        }, /*#__PURE__*/React.createElement(Wrapper, {
          data: field,
          key: field.uuid,
          first: count === 1,
          last: count === total,
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 203,
            columnNumber: 11
          }
        })))];
      });
    });

    _defineProperty(_assertThisInitialized(_this), "submitForm", function () {
      _this.props.onSubmit(_this.props.data);
    });

    _defineProperty(_assertThisInitialized(_this), "reorderFields", function (previousIndex, nextIndex) {
      if (previousIndex < nextIndex) {
        var _this$fields;

        var dragItem = _this.fields.splice(previousIndex, 1);

        console.log('sorting', dragItem, _this.fields);

        (_this$fields = _this.fields).splice.apply(_this$fields, [nextIndex - 1, 0].concat(dragItem));

        console.log('after slice', _this.fields);
      } else {
        var _this$fields2;

        console.log('before', _this.fields);

        var _dragItem = _this.fields.splice(previousIndex, 1);

        console.log('drag item', _dragItem);

        (_this$fields2 = _this.fields).splice.apply(_this$fields2, [nextIndex, 0].concat(_dragItem));
      }

      console.log('after sorting', _this.fields);
      var data = {};

      _this.fields.map(function (field, index) {
        // field.order = index + 1;
        data[field.uuid] = _extends({}, field, {
          order: index + 1
        });
      });

      _this.props.setInitialData(data);
    });

    _this.fields = {};
    _this.state = {
      loading: true,
      onDropExistingField: false
    };
    _this.onDragItem = null;
    _this.onDropItem = null;
    return _this;
  }

  var _proto = App.prototype;

  _proto.componentDidMount = function componentDidMount() {
    var _this2 = this;

    if (this.props.conditionableFields) {
      this.props.setConditionableFields(this.props.conditionableFields);
    }

    if (_.size(this.props.formData)) {
      var order = 1;

      _.map(this.props.formData, function (field) {
        if (field.order > order) {
          order = field.order;
        }
      });

      this.props.setOrder(order + 1);
    }

    if (this.props.predefinedEndpoint) {
      axios.get(this.props.predefinedEndpoint).then(function (res) {
        _this2.props.setPredefinedValues(res.data);

        _this2.setState({
          loading: false
        }, function () {
          _this2.props.setPredefinedEndpoint(_this2.props.predefinedEndpoint);

          _this2.props.setRoles(_this2.props.roles);

          _this2.props.setFileUploadUrl(_this2.props.fileUploadUrl);

          _this2.props.setInitialData(_this2.props.formData);

          if (_this2.props.onDataLoaded) _this2.props.onDataLoaded();
        });
      })["catch"](function (err) {
        _this2.props.setPredefinedValues([]);

        _this2.setState({
          loading: false
        });

        console.error('Unable to fetch predefined options from ' + _this2.props.predefinedEndPoint);
      });
      axios.get(this.props.predefinedEndpoint + '/getAllUserEmail').then(function (res) {
        var _res$data;

        _this2.props.setUsers(res == null ? void 0 : (_res$data = res.data) == null ? void 0 : _res$data.users);
      });
    }

    if (this.props.locals) {
      this.props.setLocals(this.props.locals);
    }

    if (this.props.formId) {
      this.props.setFormId(this.props.formId);
    }

    if (this.props.theme) {
      this.props.setTheme(this.props.theme);
    }

    if (this.props.currentLang) {
      this.props.setCurrentLang(this.props.currentLang);
    }

    this.props.initializeSubmit(this.submitForm);
  };

  _proto.componentDidUpdate = function componentDidUpdate(prevProps, prevState) {
    if (prevProps.theme.direction !== this.props.theme.direction) {
      this.props.setTheme(this.props.theme);
    }
  };

  _proto.render = function render() {
    var _this3 = this;

    if (this.state.loading) {
      return /*#__PURE__*/React.createElement(MainLayout, {
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 245,
          columnNumber: 9
        }
      }, /*#__PURE__*/React.createElement("div", {
        className: "ahfb-width-full ahfb-text-center ahfb-pt-5",
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 246,
          columnNumber: 11
        }
      }, /*#__PURE__*/React.createElement(CircularProgress, {
        color: "secondary",
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 247,
          columnNumber: 11
        }
      })));
    }

    if (_.size(this.props.data) > 0) {
      this.fields = Object.values(this.props.data);
      this.fields.sort(compare);
      return /*#__PURE__*/React.createElement(MainLayout, {
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 256,
          columnNumber: 9
        }
      }, /*#__PURE__*/React.createElement("div", {
        className: "ahfb-content-pane-main ahfb-position-relative",
        onDragOver: function onDragOver(e) {
          return e.preventDefault();
        },
        onDrop: function onDrop(e) {
          return _this3.handleFieldDrop(e);
        },
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 257,
          columnNumber: 13
        }
      }, /*#__PURE__*/React.createElement(Scrollbars, {
        style: {
          height: getHeight()
        },
        hideTracksWhenNotNeeded: true,
        autoHide: true,
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 260,
          columnNumber: 15
        }
      }, this.renderFields()), /*#__PURE__*/React.createElement("div", {
        className: "ahfb-width-full ahfb-p-2",
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 263,
          columnNumber: 15
        }
      })));
    } else {
      return /*#__PURE__*/React.createElement(MainLayout, {
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 270,
          columnNumber: 9
        }
      }, /*#__PURE__*/React.createElement("div", {
        className: "ahfb-content-pane-main ahfb-droppable-border",
        style: {
          height: getHeight()
        },
        onDragOver: function onDragOver(e) {
          return e.preventDefault();
        },
        onDrop: function onDrop(e) {
          return _this3.handleFieldDrop(e);
        },
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 271,
          columnNumber: 11
        }
      }, /*#__PURE__*/React.createElement("p", {
        className: "ahfb-pt-5 ahfb-text-center ahfb-text-muted",
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 274,
          columnNumber: 12
        }
      }, noFieldMessage[this.props.currentLang])));
    }
  };

  return App;
}(Component);

var mapStateToProps = function mapStateToProps(state) {
  return {
    data: state.form.data,
    order: state.form.order
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {
    setPredefinedValues: function setPredefinedValues(data) {
      return dispatch(_setPredefinedValues(data));
    },
    setUsers: function setUsers(data) {
      return dispatch(_setUsers(data));
    },
    setRoles: function setRoles(data) {
      return dispatch(_setRoles(data));
    },
    setPredefinedEndpoint: function setPredefinedEndpoint(data) {
      return dispatch(_setPredefinedEndpoint(data));
    },
    setFileUploadUrl: function setFileUploadUrl(data) {
      return dispatch(_setFileUploadUrl(data));
    },
    setInitialData: function setInitialData(data) {
      return dispatch(_setInitialData(data));
    },
    setConditionableFields: function setConditionableFields(data) {
      return dispatch(_setConditionableFields(data));
    },
    setOrder: function setOrder(data) {
      return dispatch(_setOrder(data));
    },
    createField: function createField(data) {
      return dispatch(_createField(data));
    },
    setLocals: function setLocals(data) {
      return dispatch(_setLocals(data));
    },
    setFormId: function setFormId(data) {
      return dispatch(_setFormId(data));
    },
    setTheme: function setTheme(data) {
      return dispatch(_setTheme(data));
    },
    setCurrentLang: function setCurrentLang(data) {
      return dispatch(_setCurrentLang(data));
    }
  };
};

export default connect(mapStateToProps, mapDispatchToProps)(App);

==> ah-formbuilder-1.0.92.tgz: package/es/components/app/App.js <==
var _jsxFileName = "/home/zaman/Documents/GitLab/bayt/formbuilder/src/components/app/App.js";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import { connect } from 'react-redux';
import CircularProgress from '@material-ui/core/CircularProgress';
import { setInitialData as _setInitialData, setPredefinedValues as _setPredefinedValues, setUsers as _setUsers, setPredefinedEndpoint as _setPredefinedEndpoint, setFileUploadUrl as _setFileUploadUrl, setOrder as _setOrder, setConditionableFields as _setConditionableFields, createField as _createField, setLocals as _setLocals, setFormId as _setFormId, setTheme as _setTheme, setCurrentLang as _setCurrentLang, setRoles as _setRoles, setAllRoles as _setAllRoles } from '../../actions/formActions';
import MainLayout from '../../layouts/Main';
import predefined from '../../predefined-values';
import './App.scss';
import _ from 'lodash';
import axios from 'axios';
import Wrapper from './FieldWrapper';
import DroppableField from './DroppableField';
import { Scrollbars } from 'react-custom-scrollbars';
import { getHeight, generateSampleData } from '../../utils/helpers';
var noFieldMessage = {
  en: 'Looks like there are no fields in this form',
  ar: 'يبدو أنه لا توجد حقول في هذا النموذج'
};

var compare = function compare(a, b) {
  if (a.order < b.order) {
    return -1;
  }

  if (a.order > b.order) {
    return 1;
  }

  return 0;
};

var App = /*#__PURE__*/function (_Component) {
  _inheritsLoose(App, _Component);

  function App(props) {
    var _this;

    _this = _Component.call(this, props) || this;

    _defineProperty(_assertThisInitialized(_this), "handleOnDragStart", function (index) {
      _this.onDragItem = index;

      _this.setState(_extends({}, _this.state, {
        onDragExisitingField: true
      }));
    });

    _defineProperty(_assertThisInitialized(_this), "handleOnDrop", function (index, type, uuid, order, event, callback) {
      event.stopPropagation();
      var droppedFieldSlug = event.dataTransfer.getData('droppedFieldSlug');

      if (droppedFieldSlug) {
        if (type === 'section' && droppedFieldSlug !== 'section') {
          var data = generateSampleData(droppedFieldSlug, order);
          data.parentId = uuid;

          _this.props.createField(data);
        }
      } else {
        _this.onDropItem = index;

        _this.reorderFields(_this.onDragItem, _this.onDropItem);

        callback ? callback() : null;

        _this.setState(_extends({}, _this.state, {
          onDragExisitingField: false
        }));
      }
    });

    _defineProperty(_assertThisInitialized(_this), "handleFieldDrop", function (e) {
      e.preventDefault();
      var droppedFieldSlug = e.dataTransfer.getData('droppedFieldSlug');

      if (droppedFieldSlug) {
        var data = generateSampleData(droppedFieldSlug, _this.props.order);

        _this.props.createField(data);
      }
    });

    _defineProperty(_assertThisInitialized(_this), "handleFieldDropBtw", function (e, order, callback) {
      e.stopPropagation();
      var droppedFieldSlug = e.dataTransfer.getData('droppedFieldSlug');

      if (droppedFieldSlug) {
        var data = generateSampleData(droppedFieldSlug, order);

        _this.props.createField(data);
      }

      callback();
    });

    _defineProperty(_assertThisInitialized(_this), "renderFields", function () {
      //  this.fields  = this.fields.filter(field =>{
      //   if(field.parentId) return false;
      //   return true;
      // })
      var count = 0;
      var total = _this.fields.length;
      return _.map(_this.fields, function (field, index) {
        count++;
        var droppableField = /*#__PURE__*/React.createElement(DroppableField, {
          onDrop: _this.handleFieldDropBtw,
          order: field.order,
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 176,
            columnNumber: 29
          }
        });

        if (_this.state.onDragExisitingField) {
          droppableField = /*#__PURE__*/React.createElement(DroppableField, {
            onDragExisitingField: true,
            onDrop: _this.handleOnDrop,
            data: {
              index: index,
              field: field
            },
            __self: _assertThisInitialized(_this),
            __source: {
              fileName: _jsxFileName,
              lineNumber: 178,
              columnNumber: 27
            }
          });
        }

        if (count === total) {
          var lastDroppableField = /*#__PURE__*/React.createElement(DroppableField, {
            onDragExisitingField: true,
            onDrop: _this.handleOnDrop,
            data: {
              index: index + 1,
              field: field
            },
            __self: _assertThisInitialized(_this),
            __source: {
              fileName: _jsxFileName,
              lineNumber: 181,
              columnNumber: 36
            }
          });
          return [droppableField, /*#__PURE__*/React.createElement("div", {
            key: index,
            draggable: "true",
            onDragStart: function onDragStart() {
              return _this.handleOnDragStart(index);
            } // onDrop={(e) => this.handleOnDrop(index,field.type,field.uuid,field.order,e)}
            ,
            onDragOver: function onDragOver(event) {
              return event.preventDefault();
            },
            __self: _assertThisInitialized(_this),
            __source: {
              fileName: _jsxFileName,
              lineNumber: 184,
              columnNumber: 13
            }
          }, /*#__PURE__*/React.createElement("li", {
            key: 'li-' + field.uuid,
            className: "ahfb-d-block",
            __self: _assertThisInitialized(_this),
            __source: {
              fileName: _jsxFileName,
              lineNumber: 189,
              columnNumber: 15
            }
          }, /*#__PURE__*/React.createElement(Wrapper, {
            data: field,
            key: field.uuid,
            first: count === 1,
            last: count === total,
            __self: _assertThisInitialized(_this),
            __source: {
              fileName: _jsxFileName,
              lineNumber: 190,
              columnNumber: 17
            }
          }))), lastDroppableField];
        }

        return [droppableField, /*#__PURE__*/React.createElement("div", {
          draggable: "true",
          onDragStart: function onDragStart() {
            return _this.handleOnDragStart(index);
          } // onDrop={(e) => this.handleOnDrop(index,field.type,field.uuid,field.order,e)}
          ,
          onDragOver: function onDragOver(event) {
            return event.preventDefault();
          },
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 199,
            columnNumber: 9
          }
        }, /*#__PURE__*/React.createElement("li", {
          key: 'li-' + field.uuid,
          className: "ahfb-d-block",
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 204,
            columnNumber: 9
          }
        }, /*#__PURE__*/React.createElement(Wrapper, {
          data: field,
          key: field.uuid,
          first: count === 1,
          last: count === total,
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 205,
            columnNumber: 11
          }
        })))];
      });
    });

    _defineProperty(_assertThisInitialized(_this), "submitForm", function () {
      _this.props.onSubmit(_this.props.data);
    });

    _defineProperty(_assertThisInitialized(_this), "reorderFields", function (previousIndex, nextIndex) {
      if (previousIndex < nextIndex) {
        var _this$fields;

        var dragItem = _this.fields.splice(previousIndex, 1);

        console.log('sorting', dragItem, _this.fields);

        (_this$fields = _this.fields).splice.apply(_this$fields, [nextIndex - 1, 0].concat(dragItem));

        console.log('after slice', _this.fields);
      } else {
        var _this$fields2;

        console.log('before', _this.fields);

        var _dragItem = _this.fields.splice(previousIndex, 1);

        console.log('drag item', _dragItem);

        (_this$fields2 = _this.fields).splice.apply(_this$fields2, [nextIndex, 0].concat(_dragItem));
      }

      console.log('after sorting', _this.fields);
      var data = {};

      _this.fields.map(function (field, index) {
        // field.order = index + 1;
        data[field.uuid] = _extends({}, field, {
          order: index + 1
        });
      });

      _this.props.setInitialData(data);
    });

    _this.fields = {};
    _this.state = {
      loading: true,
      onDropExistingField: false
    };
    _this.onDragItem = null;
    _this.onDropItem = null;
    return _this;
  }

  var _proto = App.prototype;

  _proto.componentDidMount = function componentDidMount() {
    var _this2 = this;

    if (this.props.conditionableFields) {
      this.props.setConditionableFields(this.props.conditionableFields);
    }

    if (_.size(this.props.formData)) {
      var order = 1;

      _.map(this.props.formData, function (field) {
        if (field.order > order) {
          order = field.order;
        }
      });

      this.props.setOrder(order + 1);
    }

    if (this.props.predefinedEndpoint) {
      axios.get(this.props.predefinedEndpoint).then(function (res) {
        _this2.props.setPredefinedValues(res.data);

        _this2.setState({
          loading: false
        }, function () {
          _this2.props.setPredefinedEndpoint(_this2.props.predefinedEndpoint);

          _this2.props.setRoles(_this2.props.roles);

          _this2.props.setAllRoles(_this2.props.allRoles);

          _this2.props.setFileUploadUrl(_this2.props.fileUploadUrl);

          _this2.props.setInitialData(_this2.props.formData);

          if (_this2.props.onDataLoaded) _this2.props.onDataLoaded();
        });
      })["catch"](function (err) {
        _this2.props.setPredefinedValues([]);

        _this2.setState({
          loading: false
        });

        console.error('Unable to fetch predefined options from ' + _this2.props.predefinedEndPoint);
      });
      axios.get(this.props.predefinedEndpoint + '/getAllUserEmail').then(function (res) {
        var _res$data;

        _this2.props.setUsers(res == null ? void 0 : (_res$data = res.data) == null ? void 0 : _res$data.users);
      });
    }

    if (this.props.locals) {
      this.props.setLocals(this.props.locals);
    }

    if (this.props.formId) {
      this.props.setFormId(this.props.formId);
    }

    if (this.props.theme) {
      this.props.setTheme(this.props.theme);
    }

    if (this.props.currentLang) {
      this.props.setCurrentLang(this.props.currentLang);
    }

    this.props.initializeSubmit(this.submitForm);
  };

  _proto.componentDidUpdate = function componentDidUpdate(prevProps, prevState) {
    if (prevProps.theme.direction !== this.props.theme.direction) {
      this.props.setTheme(this.props.theme);
    }
  };

  _proto.render = function render() {
    var _this3 = this;

    if (this.state.loading) {
      return /*#__PURE__*/React.createElement(MainLayout, {
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 247,
          columnNumber: 9
        }
      }, /*#__PURE__*/React.createElement("div", {
        className: "ahfb-width-full ahfb-text-center ahfb-pt-5",
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 248,
          columnNumber: 11
        }
      }, /*#__PURE__*/React.createElement(CircularProgress, {
        color: "secondary",
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 249,
          columnNumber: 11
        }
      })));
    }

    if (_.size(this.props.data) > 0) {
      this.fields = Object.values(this.props.data);
      this.fields.sort(compare);
      return /*#__PURE__*/React.createElement(MainLayout, {
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 258,
          columnNumber: 9
        }
      }, /*#__PURE__*/React.createElement("div", {
        className: "ahfb-content-pane-main ahfb-position-relative",
        onDragOver: function onDragOver(e) {
          return e.preventDefault();
        },
        onDrop: function onDrop(e) {
          return _this3.handleFieldDrop(e);
        },
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 259,
          columnNumber: 13
        }
      }, /*#__PURE__*/React.createElement(Scrollbars, {
        style: {
          height: getHeight()
        },
        hideTracksWhenNotNeeded: true,
        autoHide: true,
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 262,
          columnNumber: 15
        }
      }, this.renderFields()), /*#__PURE__*/React.createElement("div", {
        className: "ahfb-width-full ahfb-p-2",
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 265,
          columnNumber: 15
        }
      })));
    } else {
      return /*#__PURE__*/React.createElement(MainLayout, {
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 272,
          columnNumber: 9
        }
      }, /*#__PURE__*/React.createElement("div", {
        className: "ahfb-content-pane-main ahfb-droppable-border",
        style: {
          height: getHeight()
        },
        onDragOver: function onDragOver(e) {
          return e.preventDefault();
        },
        onDrop: function onDrop(e) {
          return _this3.handleFieldDrop(e);
        },
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 273,
          columnNumber: 11
        }
      }, /*#__PURE__*/React.createElement("p", {
        className: "ahfb-pt-5 ahfb-text-center ahfb-text-muted",
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 276,
          columnNumber: 12
        }
      }, noFieldMessage[this.props.currentLang])));
    }
  };

  return App;
}(Component);

var mapStateToProps = function mapStateToProps(state) {
  return {
    data: state.form.data,
    order: state.form.order
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {
    setPredefinedValues: function setPredefinedValues(data) {
      return dispatch(_setPredefinedValues(data));
    },
    setUsers: function setUsers(data) {
      return dispatch(_setUsers(data));
    },
    setRoles: function setRoles(data) {
      return dispatch(_setRoles(data));
    },
    setAllRoles: function setAllRoles(data) {
      return dispatch(_setAllRoles(data));
    },
    setPredefinedEndpoint: function setPredefinedEndpoint(data) {
      return dispatch(_setPredefinedEndpoint(data));
    },
    setFileUploadUrl: function setFileUploadUrl(data) {
      return dispatch(_setFileUploadUrl(data));
    },
    setInitialData: function setInitialData(data) {
      return dispatch(_setInitialData(data));
    },
    setConditionableFields: function setConditionableFields(data) {
      return dispatch(_setConditionableFields(data));
    },
    setOrder: function setOrder(data) {
      return dispatch(_setOrder(data));
    },
    createField: function createField(data) {
      return dispatch(_createField(data));
    },
    setLocals: function setLocals(data) {
      return dispatch(_setLocals(data));
    },
    setFormId: function setFormId(data) {
      return dispatch(_setFormId(data));
    },
    setTheme: function setTheme(data) {
      return dispatch(_setTheme(data));
    },
    setCurrentLang: function setCurrentLang(data) {
      return dispatch(_setCurrentLang(data));
    }
  };
};

export default connect(mapStateToProps, mapDispatchToProps)(App);
